# napari-camera

A Napari plugin that provides control over camera settings and allows saving and loading full
viewer configurations to easily recreate and share consistent visual perspectives.

## Installation

You can install `napari-camera` via [pip]:

```
pip install napari-camera
```

## License

Distributed under the terms of the [Apache Software License 2.0] license,
"napari-camera" is free and open source software

# Acknowledgments

<p align="left">
  <img src="https://github.com/MIC-DKFZ/napari-camera/raw/main/imgs/Logos/HI_Logo.png" width="150"> &nbsp;&nbsp;&nbsp;&nbsp;
  <img src="https://github.com/MIC-DKFZ/napari-camera/raw/main/imgs/Logos/DKFZ_Logo.png" width="500">
</p>

This repository is developed and maintained by the Applied Computer Vision Lab (ACVL)
of [Helmholtz Imaging](https://www.helmholtz-imaging.de/) and the
[Division of Medical Image Computing](https://www.dkfz.de/en/medical-image-computing) at DKFZ.

This [napari] plugin was generated with [copier] using the [napari-plugin-template].

[apache software license 2.0]: http://www.apache.org/licenses/LICENSE-2.0
[copier]: https://copier.readthedocs.io/en/stable/
[napari]: https://github.com/napari/napari
[napari-plugin-template]: https://github.com/napari/napari-plugin-template
[pip]: https://pypi.org/project/pip/
